@@ -1,62 +1,68 @@
 """
-This module defines the ``happi`` command line utility
+This module defines the ``happi`` command line interface.
 """
-# cli.py
-
 import argparse
 import fnmatch
+import json
 import logging
 import os
 import sys
 
 import coloredlogs
-from IPython import start_ipython
-from .utils import is_a_range
 
 import happi
 
+from .utils import is_a_range
+
 logger = logging.getLogger(__name__)
 
 
 def get_parser():
-    """
-    Defines HAPPI shell commands
-    """
+    """Defines HAPPI shell commands."""
     # Argument Parser Setup
-    parser = argparse.ArgumentParser(description='happi command line tool')
+    parser = argparse.ArgumentParser(description='Happi command line tool')
 
     # Optional args general to all happi operations
     parser.add_argument('--path', type=str,
-                        help='path to happi configuration file')
+                        help='Provide the path to happi configuration file.')
     parser.add_argument('--verbose', '-v', action='store_true',
-                        help='Show the degub logging stream')
+                        help='Show the debug logging stream.')
     parser.add_argument('--version', '-V', action='store_true',
-                        help='Current version and location '
-                        'of Happi installation.')
+                        help='Show the current version and location of Happi '
+                             'installation.')
     # Subparser to trigger search arguments
-    subparsers = parser.add_subparsers(help='Subparsers to search, add, edit',
-                                       dest='cmd')
+    subparsers = parser.add_subparsers(help='Subcommands used to search, add, '
+                                       'edit, or load entries', dest='cmd')
     parser_search = subparsers.add_parser('search', help='Search the happi '
-                                          'database')
+                                          'database.')
+    parser_search.add_argument('--json', action='store_true',
+                               help='Show results in JSON format.')
     parser_search.add_argument('search_criteria', nargs='+',
-                               help='Search criteria: '
-                               'field=value. If field= is '
-                               'omitted, it will be assumed to be "name". '
-                               'You may include as many search criteria as '
-                               'you like.')
-    parser_add = subparsers.add_parser('add', help='Add new entries')
+                               help='Search criteria of the form: '
+                               'field=value. If "field=" is omitted, it will '
+                               'be assumed to be "name". You may include as '
+                               'many search criteria as you like; these will '
+                               'be combined swith ANDs.')
+    parser_add = subparsers.add_parser('add',
+                                       help='Add new entries interactively.')
     parser_add.add_argument('--clone', default='',
-                            help='Name of device to use for default parameters'
-                            )
-    parser_edit = subparsers.add_parser('edit', help='Change existing entry')
-    parser_edit.add_argument('name', help='Device to edit')
+                            help='Copy the fields from an existing container. '
+                                 'Provide the name of the item to clone.')
+    parser_edit = subparsers.add_parser('edit',
+                                        help='Change an existing entry.')
+    parser_edit.add_argument('name', help='Name of the item to edit')
     parser_edit.add_argument('edits', nargs='+',
-                             help='Edits of the form field=value')
+                             help='Edits of the form: field=value')
     parser_load = subparsers.add_parser('load',
-                                        help='Open IPython terminal with '
-                                        'device loaded')
+                                        help='Open IPython terminal with a '
+                                        'given device loaded.')
     parser_load.add_argument('device_names', nargs='+',
-                             help='Devices to load')
+                             help='The names of one or more devices to load')
+    parser_update = subparsers.add_parser("update",
+                                          help="Update happi db "
+                                          "with JSON payload.")
+    parser_update.add_argument("json", help="JSON payload.",
+                               default="-", nargs="*")
     return parser
 
 
@@ -146,21 +152,26 @@ def happi_cli(args):
         # we only want to return the ones that have been repeated when
         # they have been matched with both search_regex() & search_range()
         if repeated:
-            for res in repeated:
-                res.item.show_info()
-            return repeated
-        # only matched with search_regex()
+            final_results = repeated
         elif regex_list and not is_range:
-            for res in regex_list:
-                res.item.show_info()
-            return regex_list
-        # only matched with search_range()
+            # only matched with search_regex()
+            final_results = regex_list
         elif range_list and is_range:
-            for res in range_list:
-                res.item.show_info()
-            return range_list
+            # only matched with search_range()
+            final_results = range_list
         else:
+            final_results = []
+
+        if args.json:
+            json.dump([dict(res.item) for res in final_results], indent=2,
+                      fp=sys.stdout)
+        else:
+            for res in final_results:
+                res.item.show_info()
+
+        if not final_results:
             logger.error('No devices found')
+        return final_results
     elif args.cmd == 'add':
         logger.debug('Starting interactive add')
         registry = happi.containers.registry
@@ -243,7 +254,21 @@ def happi_cli(args):
         devices = {}
         for name in args.device_names:
             devices[name] = client.load_device(name=name)
+
+        from IPython import start_ipython  # noqa
         start_ipython(argv=['--quick'], user_ns=devices)
+    elif args.cmd == "update":
+        # parse input
+        input_ = " ".join(args.json).strip()
+        if input_ == "-":
+            items_input = json.load(sys.stdin)
+        else:
+            items_input = json.loads(input_)
+        # insert
+        for item in items_input:
+            item = client.create_device(device_cls=item["type"], **item)
+            exists = item["_id"] in [c["_id"] for c in client.all_items]
+            client._store(item, insert=not exists)
 
 
 def main():
